@@ -1,14 +1,14 @@
 package MasonX::Interp::WithCallbacks;
 
 use strict;
-use HTML::Mason qw(1.23);
+use HTML::Mason 1.23;
 use HTML::Mason::Interp;
 use HTML::Mason::Exceptions ();
 use Params::CallbackRequest;
 
 use vars qw($VERSION @ISA);
 @ISA = qw(HTML::Mason::Interp);
-$VERSION = '1.18';
+$VERSION = '1.20';
 
 Params::Validate::validation_options
   ( on_fail => sub { HTML::Mason::Exception::Params->throw( join '', @_ ) } );
@@ -848,6 +848,14 @@ In this example, we have overridden the component path determined by the
 Mason resolver in favor of an alternate component, which will be executed,
 instead.
 
+=head3 make_request
+
+Overrides and re-dispatches to L<HTML::Mason::Interp/"make_request">.
+
+=head3 purge_code_cache
+
+Overrides and re-dispatches to L<HTML::Mason::Interp/"purge_code_cache">.
+
 =head2 Requester
 
 The MasonX::Interp::WithCallbacks object is available in all callback methods
@@ -875,12 +883,12 @@ request, just as with C<< $r->pnotes >>.
 
 =head1 SUPPORT
 
-This module is stored in an open repository at the following address:
+This module is stored in a public
+L<GitHub repository|https://github.com/theory/masonx-interp-withcallbacks/>. Feel free to
+fork and contribute!
 
-L<https://svn.kineticode.com/MasonX-Interp-WithCallbacks/trunk/>
-
-Patches against SVN::Notify are welcome. Please send bug reports to
-<bug-MasonX-interp-withcallbacks@rt.cpan.org>.
+Please file bug reports via
+L<GitHub Issues|https://github.com/theory/masonx-interp-withcallbacks/issues/>.
 
 =head1 SEE ALSO
 
@@ -897,16 +905,16 @@ create callback classes and methods.
 
 This module works with L<HTML::Mason|HTML::Mason> by subclassing
 L<HTML::Mason::Interp|HTML::Mason::Interp>. Inspired by the implementation of
-callbacks in Bricolage (L<http://bricolage.cc/>), it is however a completely
+callbacks in Bricolage (L<http://bricolagecms.org/>), it is however a completely
 new code base with a rather different approach.
 
 =head1 AUTHOR
 
-David Wheeler <david@kineticode.com>
+David E. Wheeler <david@justatheory.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2008 by David Wheeler. Some Rights Reserved.
+Copyright 2003-2024 by David E. Wheeler. Some Rights Reserved.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
